# COST02-BP05: Implement cost controls

## Description

Set up budgets, alerts, và spending limits.

## Implementation Guidance

- Configure budget alerts
- Set spending limits per account
- Implement approval for large purchases
- Auto-stop non-essential resources
- Review controls effectiveness

## Risk Level

High - Without controls, costs can spike unexpectedly.

## Related Best Practices

- [COST02-BP01](COST02-BP01-Cost-Policies.md)
- [COST01-BP03](../COST01-Practice-Cloud-Financial-Management/COST01-BP03-Budgets-Forecasts.md)
